==> flutter_zendes_plugin-0.9.0.tar.gz: lib/flutter_zendes_plugin.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:package_info/package_info.dart';

class FlutterZendeskPlugin {
  static const MethodChannel _channel =
      const MethodChannel('flutter_zendes_plugin');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    debugPrint('version = "$version"');
    return version;
  }

  Future<void> init(String accountKey,
      {String applicationId, String clientId, String domainUrl,String nameIdentifier,String emailIdentifier}) async {
    if (applicationId == null || applicationId.isEmpty) {
      PackageInfo pi = await PackageInfo.fromPlatform();
      applicationId = '${pi.appName}, v${pi.version}(${pi.buildNumber})';
    }
    debugPrint('Init with applicationId="$applicationId"');
    final String result = await _channel.invokeMethod('init', <String, dynamic>{
      'accountKey': accountKey,
      'applicationId': applicationId,
      'clientId': clientId,
      'domainUrl': domainUrl,
      'emailIdentifier': emailIdentifier,
      'nameIdentifier': nameIdentifier,
    });
    debugPrint('Init result ="$result"');
  }

  Future<void> startChat({String phone, String name, String email,String botLabel,String toolbarTitle,String departmentName}) async {
    return await _channel.invokeMethod('startChat', <String, dynamic>{
      'phone': phone,
      'email': email,
      'name': name,
      'botLabel': botLabel,
      'toolbarTitle': toolbarTitle,
      'departmentName': departmentName,
    });
  }

  Future<dynamic> helpCenter() async {
    return await _channel.invokeMethod('helpCenter');
  }
}

==> flutter_zendes_plugin-0.9.4.tar.gz: lib/flutter_zendes_plugin.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:package_info/package_info.dart';

class FlutterZendeskPlugin {
  static const MethodChannel _channel =
      const MethodChannel('flutter_zendes_plugin');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    debugPrint('version = "$version"');
    return version;
  }

  Future<void> init(String accountKey,
      {String applicationId,
      String clientId,
      String domainUrl,
      String nameIdentifier,
      String emailIdentifier,
      String phone,
      String name,
      String email,
      String departmentName}) async {
    if (applicationId == null || applicationId.isEmpty) {
      PackageInfo pi = await PackageInfo.fromPlatform();
      applicationId = '${pi.appName}, v${pi.version}(${pi.buildNumber})';
    }
    debugPrint('Init with applicationId="$applicationId"');
    final String result = await _channel.invokeMethod('init', <String, dynamic>{
      'accountKey': accountKey,
      'applicationId': applicationId,
      'clientId': clientId,
      'domainUrl': domainUrl,
      'emailIdentifier': emailIdentifier,
      'nameIdentifier': nameIdentifier,
      'phone': phone,
      'email': email,
      'name': name,
      'departmentName': departmentName,
    });
    debugPrint('Init result ="$result"');
  }

  Future<void> startChatV1() async {
    return await _channel.invokeMethod('startChatV1');
  }

  Future<void> startChatV2(
      {String phone,
      String name,
      String email,
      String departmentName,
      String botLabel,
      String toolbarTitle}) async {
    return await _channel.invokeMethod('startChatV2', <String, dynamic>{
      phone: phone,
      name: name,
      email: email,
      departmentName: departmentName,
      'botLabel': botLabel,
      'toolbarTitle': toolbarTitle,
    });
  }

  Future<dynamic> helpCenter() async {
    return await _channel.invokeMethod('helpCenter');
  }
}
